@@ -1,28 +1,37 @@
 import StackdriverDataSource from '../datasource';
 import { metricDescriptors } from './testData';
-import moment from 'moment';
 import { TemplateSrv } from 'app/features/templating/template_srv';
 import { CustomVariable } from 'app/features/templating/all';
+import { toUtc } from '@grafana/data';
+import { DataSourceInstanceSettings } from '@grafana/ui';
+import { StackdriverOptions } from '../types';
+import { BackendSrv } from 'app/core/services/backend_srv';
+import { TimeSrv } from 'app/features/dashboard/services/TimeSrv';
+
+interface Result {
+  status: any;
+  message?: any;
+}
 
 describe('StackdriverDataSource', () => {
-  const instanceSettings = {
+  const instanceSettings = ({
     jsonData: {
       defaultProject: 'testproject',
     },
-  };
+  } as unknown) as DataSourceInstanceSettings<StackdriverOptions>;
   const templateSrv = new TemplateSrv();
-  const timeSrv = {};
+  const timeSrv = {} as TimeSrv;
 
   describe('when performing testDataSource', () => {
     describe('and call to stackdriver api succeeds', () => {
       let ds;
-      let result;
+      let result: Result;
       beforeEach(async () => {
-        const backendSrv = {
+        const backendSrv = ({
           async datasourceRequest() {
             return Promise.resolve({ status: 200 });
           },
-        };
+        } as unknown) as BackendSrv;
         ds = new StackdriverDataSource(instanceSettings, backendSrv, templateSrv, timeSrv);
         result = await ds.testDatasource();
       });
@@ -33,11 +42,11 @@ describe('StackdriverDataSource', () => {
 
     describe('and a list of metricDescriptors are returned', () => {
       let ds;
-      let result;
+      let result: Result;
       beforeEach(async () => {
-        const backendSrv = {
+        const backendSrv = ({
           datasourceRequest: async () => Promise.resolve({ status: 200, data: metricDescriptors }),
-        };
+        } as unknown) as BackendSrv;
         ds = new StackdriverDataSource(instanceSettings, backendSrv, templateSrv, timeSrv);
         result = await ds.testDatasource();
       });
@@ -48,9 +57,9 @@ describe('StackdriverDataSource', () => {
 
     describe('and call to stackdriver api fails with 400 error', () => {
       let ds;
-      let result;
+      let result: Result;
       beforeEach(async () => {
-        const backendSrv = {
+        const backendSrv = ({
           datasourceRequest: async () =>
             Promise.reject({
               statusText: 'Bad Request',
@@ -58,7 +67,7 @@ describe('StackdriverDataSource', () => {
                 error: { code: 400, message: 'Field interval.endTime had an invalid value' },
               },
             }),
-        };
+        } as unknown) as BackendSrv;
         ds = new StackdriverDataSource(instanceSettings, backendSrv, templateSrv, timeSrv);
         result = await ds.testDatasource();
       });
@@ -73,8 +82,8 @@ describe('StackdriverDataSource', () => {
   describe('When performing query', () => {
     const options = {
       range: {
-        from: moment.utc('2017-08-22T20:00:00Z'),
-        to: moment.utc('2017-08-22T23:59:00Z'),
+        from: toUtc('2017-08-22T20:00:00Z'),
+        to: toUtc('2017-08-22T23:59:00Z'),
       },
       rangeRaw: {
         from: 'now-4h',
@@ -88,8 +97,8 @@ describe('StackdriverDataSource', () => {
     };
 
     describe('and no time series data is returned', () => {
-      let ds;
-      const response = {
+      let ds: StackdriverDataSource;
+      const response: any = {
         results: {
           A: {
             refId: 'A',
@@ -103,14 +112,14 @@ describe('StackdriverDataSource', () => {
       };
 
       beforeEach(() => {
-        const backendSrv = {
+        const backendSrv = ({
           datasourceRequest: async () => Promise.resolve({ status: 200, data: response }),
-        };
+        } as unknown) as BackendSrv;
         ds = new StackdriverDataSource(instanceSettings, backendSrv, templateSrv, timeSrv);
       });
 
       it('should return a list of datapoints', () => {
-        return ds.query(options).then(results => {
+        return ds.query(options as any).then(results => {
           expect(results.data.length).toBe(0);
         });
       });
@@ -120,9 +129,9 @@ describe('StackdriverDataSource', () => {
   describe('when performing getMetricTypes', () => {
     describe('and call to stackdriver api succeeds', () => {});
     let ds;
-    let result;
+    let result: any;
     beforeEach(async () => {
-      const backendSrv = {
+      const backendSrv = ({
         async datasourceRequest() {
           return Promise.resolve({
             data: {
@@ -139,8 +148,9 @@ describe('StackdriverDataSource', () => {
             },
           });
         },
-      };
+      } as unknown) as BackendSrv;
       ds = new StackdriverDataSource(instanceSettings, backendSrv, templateSrv, timeSrv);
+      // @ts-ignore
       result = await ds.getMetricTypes();
     });
     it('should return successfully', () => {
@@ -155,12 +165,14 @@ describe('StackdriverDataSource', () => {
     });
   });
 
+  const noopBackendSrv = ({} as unknown) as BackendSrv;
+
   describe('when interpolating a template variable for the filter', () => {
-    let interpolated;
+    let interpolated: any[];
     describe('and is single value variable', () => {
       beforeEach(() => {
         const filterTemplateSrv = initTemplateSrv('filtervalue1');
-        const ds = new StackdriverDataSource(instanceSettings, {}, filterTemplateSrv, timeSrv);
+        const ds = new StackdriverDataSource(instanceSettings, noopBackendSrv, filterTemplateSrv, timeSrv);
         interpolated = ds.interpolateFilters(['resource.label.zone', '=~', '${test}'], {});
       });
 
@@ -173,7 +185,7 @@ describe('StackdriverDataSource', () => {
     describe('and is multi value variable', () => {
       beforeEach(() => {
         const filterTemplateSrv = initTemplateSrv(['filtervalue1', 'filtervalue2'], true);
-        const ds = new StackdriverDataSource(instanceSettings, {}, filterTemplateSrv, timeSrv);
+        const ds = new StackdriverDataSource(instanceSettings, noopBackendSrv, filterTemplateSrv, timeSrv);
         interpolated = ds.interpolateFilters(['resource.label.zone', '=~', '[[test]]'], {});
       });
 
@@ -184,12 +196,12 @@ describe('StackdriverDataSource', () => {
   });
 
   describe('when interpolating a template variable for group bys', () => {
-    let interpolated;
+    let interpolated: any[];
 
     describe('and is single value variable', () => {
       beforeEach(() => {
         const groupByTemplateSrv = initTemplateSrv('groupby1');
-        const ds = new StackdriverDataSource(instanceSettings, {}, groupByTemplateSrv, timeSrv);
+        const ds = new StackdriverDataSource(instanceSettings, noopBackendSrv, groupByTemplateSrv, timeSrv);
         interpolated = ds.interpolateGroupBys(['[[test]]'], {});
       });
 
@@ -202,7 +214,7 @@ describe('StackdriverDataSource', () => {
     describe('and is multi value variable', () => {
       beforeEach(() => {
         const groupByTemplateSrv = initTemplateSrv(['groupby1', 'groupby2'], true);
-        const ds = new StackdriverDataSource(instanceSettings, {}, groupByTemplateSrv, timeSrv);
+        const ds = new StackdriverDataSource(instanceSettings, noopBackendSrv, groupByTemplateSrv, timeSrv);
         interpolated = ds.interpolateGroupBys(['[[test]]'], {});
       });
 
@@ -215,9 +227,9 @@ describe('StackdriverDataSource', () => {
   });
 
   describe('unit parsing', () => {
-    let ds, res;
+    let ds: StackdriverDataSource, res: any;
     beforeEach(() => {
-      ds = new StackdriverDataSource(instanceSettings, {}, templateSrv, timeSrv);
+      ds = new StackdriverDataSource(instanceSettings, noopBackendSrv, templateSrv, timeSrv);
     });
     describe('when theres only one target', () => {
       describe('and the stackdriver unit doesnt have a corresponding grafana unit', () => {
@@ -277,7 +289,7 @@ function initTemplateSrv(values: any, multi = false) {
         },
         multi: multi,
       },
-      {}
+      {} as any
     ),
   ]);
   return templateSrv;
